EquationModelCard

Struct EquationModelCard 

pub struct EquationModelCard {
Show 13 fields pub name: String, pub version: String, pub equation: String, pub class: EquationClass, pub citation: Citation, pub references: Vec<Citation>, pub variables: Vec<EquationVariable>, pub verification_tests: Vec<VerificationTest>, pub domain_constraints: Vec<DomainConstraint>, pub falsification_criteria: Vec<FalsificationCriterion>, pub implementation_notes: Vec<ImplementationNote>, pub description: String, pub lineage: Vec<String>,
}
Equation Model Card - Complete documentation for a governing equation.

An EMC must be attached to any simulation using the equation. It provides:

  • Traceability to peer-reviewed literature
  • Verification test cases from analytical solutions
  • Domain constraints for valid operation
  • Falsification criteria for scientific validity

Fields

name: String

Unique name for this EMC

version: String

Version string

equation: String

The governing equation in LaTeX

class: EquationClass

Equation classification

citation: Citation

Primary citation

references: Vec<Citation>

Additional references

variables: Vec<EquationVariable>

Variables in the equation

verification_tests: Vec<VerificationTest>

Verification tests

domain_constraints: Vec<DomainConstraint>

Domain constraints

falsification_criteria: Vec<FalsificationCriterion>

Falsification criteria

implementation_notes: Vec<ImplementationNote>

Implementation notes

description: String

Description/abstract

lineage: Vec<String>

Parent EMCs this derives from

Implementations

Source

impl EquationModelCard

pub fn builder() -> EmcBuilder

Create a new EMC builder.

pub fn from_equation<E: GoverningEquation>(equation: &E) -> EmcBuilder

Create an EMC from a GoverningEquation implementation.

pub fn run_verification_tests<F>( &self, evaluator: F, ) -> Vec<(String, bool, String)>
where F: Fn(&HashMap<String, f64>) -> f64,

Run all verification tests.

Returns a list of (test_name, passed, message) tuples.

pub fn verify<F>(&self, evaluator: F) -> Result<(), Vec<String>>
where F: Fn(&HashMap<String, f64>) -> f64,

Check if all verification tests pass.

Errors

Returns a list of failure messages if any verification tests fail.