pub fn load_yaml_experiment(
path: &Path,
) -> Result<YamlExperiment, YamlLoadError>Expand description
Load experiment from YAML file
Errors
Returns error if file doesn’t exist, has parse errors, or contains custom code
pub fn load_yaml_experiment(
path: &Path,
) -> Result<YamlExperiment, YamlLoadError>Load experiment from YAML file
Returns error if file doesn’t exist, has parse errors, or contains custom code