Dynamic Stack Discovery for Sovereign AI Stack components.
Per the Batuta Stack Review, hardcoded component lists introduce Muda of Processing (maintenance waste). This module uses dynamic discovery to detect available stack components from Cargo.toml.
Structs
- Stack
Discovery - Dynamic discovery of Sovereign AI Stack components.
- Version
- Semantic version representation.
Enums
- Stack
Component - Sovereign AI Stack components that simular can integrate with.